.. _AdminPanelOverview:

Overview
--------

Multilingual admin panel is available at ``/admin/``

  * Username: *test*
  * Password: *test*

.. image:: _static/images/admin1.png

.. image:: _static/images/admin3.png
   
.. image:: _static/images/admin2.png

.. image:: _static/images/admin4.png
